<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="id">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Jenis Proksi</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Alamat IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid port</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Putus</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Menyambung</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Putus</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Koneksi Kabel %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Koneksi PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>VPN Baru</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tipe VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Ekspor</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Jaringan</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detail Jaringan</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy Sistem</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Jaringan Kabel</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Jaringan Nirkabel</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Tambahkan Koneksi Network</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Sambungkan ke jaringan tersembunyi</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Buat Koneksi PPPoE</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Status VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Buat VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Impor VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Jenis Proksi</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurasi URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Alamat IP</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Antarmuka</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Pita</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Utama</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Awalan</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Kecepatan</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Belum Terpasang</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Alamat MAC Perangkat</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Alamat MAC Tergandakan</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Kustom MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Umum</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Umum</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Tambah Pengaturan</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Alamat IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Awalan</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatis</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Abaikan</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Alamat IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Hanya diterapkan pada sumber daya yang sesuai</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metode</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Awalan</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>Jaringan</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metode</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatis</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Abaikan</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Detail Jaringan</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy Sistem</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detail Jaringan</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Jaringan</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Nonaktifkan</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatis</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Layanan</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Tolak Autentikasi EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Tolak Autentikasi PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Tolak Autentikasi CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Tolak Autentikasi MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Tolak Autentikasi MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Tidak ada kompresi data BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Tidak ada penurunan data kompresi</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Tidak ada kompresi TCP Header</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Tidak ada kompresi Protokl Field</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Tidak ada Kompresi Alamat/Kontrol</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Kirim Paket PPP Echo</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Gunakan MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPEE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Buat Koneksi PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy Sistem</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Jenis Proksi</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatis</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Abaikan pengaturan proxy untuk host dan domain di atas</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurasi URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Keamanan</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneled TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Protected EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Nonaktifkan</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonim</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Terotentifikasi</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Keduanya</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Otomatis</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versi 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versi 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autentikasi EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opsi Pwd</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kunci Privat</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Cert Pengguna</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID Anonim</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisioning</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Berkas PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Inner Auth</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versi PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privat Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Sandi lewat tidak valid</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tidak ada</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Keamanan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Keamanan Dibutuhkan</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Sandi lewat tidak valid</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tidak ada</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Keamanan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Lanjutan</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Kustom Gateway Port</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port Gateway</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Kustom Renegosiasi Interval</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Renegosiasi Interval</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Kustom Tunnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Kustom ukuran UDP Fragment</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Ukuran UDP Fragment</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Pembatasan Tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Acak Host Remote</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Lanjutan</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (baku)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Aman (baku)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Lemah</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tidak ada</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Ketika Tersedia (baku)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Selalu NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Nonaktifkan</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2 (baku)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Peladen (baku)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domain</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Vendor</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Enkripsi</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Mode NAT Traversal</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>ID DH Group</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Teruskan Kerahasiaan</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Port Lokal</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Nonaktifkan Deteksi Dead Peer </translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Nyalakan IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nama Grup</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID Grup</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pra-Pembagian Kunci</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritma Phase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritma Phase2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Mengizinkan Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Skrip CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Cert Pengguna</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kunci Privat</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Gunakan FSID untuk Frasa Kunci</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Sertifikat (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Sertifikat dengan Kata sandi (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Kunci Statis</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Tersimpan</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Tanya</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tidak Diperlukan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipe Auth</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Cert Pengguna</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kunci Privat</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opsi Pwd</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privat Pwd</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Menyesuaikan Arah Kunci</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Pengarah</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP Remote</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP Lokal</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Semua Tersedia (baku)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (kurang aman)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (lebih aman)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Tolak Autentikasi EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Tolak Autentikasi PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Tolak Autentikasi CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Tolak Autentikasi MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Tolak Autentikasi MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Tidak ada kompresi data BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Tidak ada penurunan data kompresi</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Tidak ada kompresi TCP Header</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Tidak ada kompresi Protokl Field</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Tidak ada Kompresi Alamat/Kontrol</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Kirim Paket PPP Echo</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Gunakan MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Keamanan</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Status VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Buat VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Impor VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Impor Kesalahan</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tidak Diperlukan</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Jenis Proksi</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Peladen</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Ulangi Indefinite Ketika Gagal</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Berkas CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Abaikan peringatan sertifikat</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Keamanan VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Bawaan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tidak ada</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Chiper</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Tersimpan</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Tanya</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tidak Diperlukan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opsi Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domain NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Peladen</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kunci Privat</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Kartu Pintar</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pra-Pembagian Kunci</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipe Auth</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Cert Pengguna</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Meminta alamat IP dalam</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Terapkan Enkapsulasi UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Gunakan kompresi IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autentikasi VPN TLS</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Bawaan</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Peladen</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Subyek Cocok</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipe Remote Cert</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Berkas Kunci</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Menyesuaikan Arah Kunci</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Pengarah</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Tersimpan</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Tanya</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tidak Diperlukan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Dibutuhkan</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opsi Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sandi lewat</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nama Grup</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Sandi Grup</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Gunakan Autentikasi Ganda</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Berkas CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Tambahkan Koneksi Network</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Pilih Pengaturan</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Sambungkan ke jaringan tersembunyi</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Belum Terpasang</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Alamat MAC Perangkat</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Kustom MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pita</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Antarmuka</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Utama</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Awalan</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Kecepatan</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Perangkat non aktif</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Terhubung tetapi tidak ada akses Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Tidak tersambung</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel jaringan tidak terhubung</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Menyambung</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentikasi</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Mendapatkan alamat IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Tersambung</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Terputus</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Gagal</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Jaringan Kabel</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Jaringan Nirkabel</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Jaringan Nirkabel %1</translation>
    </message>
</context>
</TS>